@@ -1,7 +1,7 @@
 from .methods import compile, findall, match, scan, split, substitute
 from .consts import (
     __libpcre2_version__,
-    CompileOption, MatchOption, SubstituteOption, ExpandOption,
-    A, I, G, M, NE, NS, U, S, X
+    CompileOption,
+    A, I, M, U, S, X
 )
-__version__ = "0.3.0"
+__version__ = "0.4.0"
